# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: digiwave/v1/digiwave.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x64igiwave/v1/digiwave.proto\x12\x08\x64igiwave\"K\n\x10\x43onfigurationSet\x12\x13\n\x0b\x66ull_duplex\x18\x01 \x01(\x08\x12\x10\n\x08\x63laim_rx\x18\x02 \x01(\x08\x12\x10\n\x08loopback\x18\x03 \x01(\x08\"\x1a\n\x18\x43onfigurationSetResponse\"\x12\n\x10\x43onfigurationGet\"\x1a\n\x18\x43onfigurationGetResponse\"\x17\n\x15\x43onfigurationDescribe\"\x1f\n\x1d\x43onfigurationDescribeResponse\"\x14\n\x12\x46unctionControlGet\"\"\n\x12\x46unctionControlSet\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x1c\n\x1a\x46unctionControlGetResponse\"\x1c\n\x1a\x46unctionControlSetResponse\"\x14\n\x12StreamControlStart\"#\n\x06Sample\x12\x19\n\x11transitions_block\x18\x01 \x01(\x0c\"/\n\nStreamData\x12!\n\x07samples\x18\x01 \x03(\x0b\x32\x10.digiwave.SampleB\rZ\x0b\x64igiwave/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'digiwave.v1.digiwave_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\013digiwave/v1'
  _globals['_CONFIGURATIONSET']._serialized_start=40
  _globals['_CONFIGURATIONSET']._serialized_end=115
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_start=117
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_end=143
  _globals['_CONFIGURATIONGET']._serialized_start=145
  _globals['_CONFIGURATIONGET']._serialized_end=163
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_start=165
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_end=191
  _globals['_CONFIGURATIONDESCRIBE']._serialized_start=193
  _globals['_CONFIGURATIONDESCRIBE']._serialized_end=216
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_start=218
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_end=249
  _globals['_FUNCTIONCONTROLGET']._serialized_start=251
  _globals['_FUNCTIONCONTROLGET']._serialized_end=271
  _globals['_FUNCTIONCONTROLSET']._serialized_start=273
  _globals['_FUNCTIONCONTROLSET']._serialized_end=307
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_start=309
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_end=337
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_start=339
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_end=367
  _globals['_STREAMCONTROLSTART']._serialized_start=369
  _globals['_STREAMCONTROLSTART']._serialized_end=389
  _globals['_SAMPLE']._serialized_start=391
  _globals['_SAMPLE']._serialized_end=426
  _globals['_STREAMDATA']._serialized_start=428
  _globals['_STREAMDATA']._serialized_end=475
# @@protoc_insertion_point(module_scope)
