# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: canL2/v1alpha1/canL2.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63\x61nL2/v1alpha1/canL2.proto\x12\x05\x63\x61nL2\"V\n\x10\x43onfigurationSet\x12\x0c\n\x04\x62\x61ud\x18\x01 \x01(\x07\x12\x13\n\x0bsamplePoint\x18\x02 \x01(\x05\x12\x0b\n\x03sjw\x18\x03 \x01(\x05\x12\x12\n\nlistenOnly\x18\x04 \x01(\x08\"\x1a\n\x18\x43onfigurationSetResponse\"\x12\n\x10\x43onfigurationGet\"^\n\x18\x43onfigurationGetResponse\x12\x0c\n\x04\x62\x61ud\x18\x01 \x01(\x07\x12\x13\n\x0bsamplePoint\x18\x02 \x01(\x05\x12\x0b\n\x03sjw\x18\x03 \x01(\x05\x12\x12\n\nlistenOnly\x18\x04 \x01(\x08\"\x17\n\x15\x43onfigurationDescribe\"\x1f\n\x1d\x43onfigurationDescribeResponse\"\xb9\x01\n\x15\x43onfigurationResponse\x12.\n\x03get\x18\x01 \x01(\x0b\x32\x1f.canL2.ConfigurationGetResponseH\x00\x12.\n\x03set\x18\x02 \x01(\x0b\x32\x1f.canL2.ConfigurationSetResponseH\x00\x12\x38\n\x08\x64\x65scribe\x18\x03 \x01(\x0b\x32$.canL2.ConfigurationDescribeResponseH\x00\x42\x06\n\x04type\"\x14\n\x12\x46unctionControlGet\"Z\n\x05\x46rame\x12\x1b\n\x13\x65xtendedFrameFormat\x18\x01 \x01(\x08\x12\x13\n\x0bremoteFrame\x18\x02 \x01(\x08\x12\x11\n\tmessageId\x18\x03 \x01(\x07\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\"1\n\x12\x46unctionControlSet\x12\x1b\n\x05\x66rame\x18\x01 \x03(\x0b\x32\x0c.canL2.Frame\"M\n\x1a\x46unctionControlGetResponse\x12/\n\x0f\x63ontrollerState\x18\x01 \x01(\x0e\x32\x16.canL2.ControllerState\"\x1c\n\x1a\x46unctionControlSetResponse\"D\n\x12StreamControlStart\x12\x16\n\x0e\x61\x63\x63\x65ptanceCode\x18\x01 \x01(\x07\x12\x16\n\x0e\x61\x63\x63\x65ptanceMask\x18\x02 \x01(\x07\"\xa0\x01\n\x06Sample\x12\x11\n\ttimestamp\x18\x01 \x01(\x06\x12\x1b\n\x05\x66rame\x18\x02 \x01(\x0b\x32\x0c.canL2.Frame\x12/\n\x0f\x63ontrollerState\x18\x03 \x01(\x0e\x32\x16.canL2.ControllerState\x12 \n\x05\x65rror\x18\x04 \x01(\x0e\x32\x11.canL2.ErrorEvent\x12\x13\n\x0bisDataFrame\x18\x05 \x01(\x08\",\n\nStreamData\x12\x1e\n\x07samples\x18\x01 \x03(\x0b\x32\r.canL2.Sample*E\n\x0f\x43ontrollerState\x12\n\n\x06\x43\x41N_OK\x10\x00\x12\x15\n\x11\x43\x41N_ERROR_PASSIVE\x10\x01\x12\x0f\n\x0b\x43\x41N_BUS_OFF\x10\x02*m\n\nErrorEvent\x12\x10\n\x0c\x43\x41N_NO_ERROR\x10\x00\x12\x11\n\rCAN_TX_FAILED\x10\x01\x12\x15\n\x11\x43\x41N_RX_QUEUE_FULL\x10\x02\x12\x10\n\x0c\x43\x41N_ARB_LOST\x10\x03\x12\x11\n\rCAN_BUS_ERROR\x10\x04\x42\x10Z\x0e\x63\x61nL2/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'canL2.v1alpha1.canL2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\016canL2/v1alpha1'
  _globals['_CONTROLLERSTATE']._serialized_start=1068
  _globals['_CONTROLLERSTATE']._serialized_end=1137
  _globals['_ERROREVENT']._serialized_start=1139
  _globals['_ERROREVENT']._serialized_end=1248
  _globals['_CONFIGURATIONSET']._serialized_start=37
  _globals['_CONFIGURATIONSET']._serialized_end=123
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_start=125
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_end=151
  _globals['_CONFIGURATIONGET']._serialized_start=153
  _globals['_CONFIGURATIONGET']._serialized_end=171
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_start=173
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_end=267
  _globals['_CONFIGURATIONDESCRIBE']._serialized_start=269
  _globals['_CONFIGURATIONDESCRIBE']._serialized_end=292
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_start=294
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_end=325
  _globals['_CONFIGURATIONRESPONSE']._serialized_start=328
  _globals['_CONFIGURATIONRESPONSE']._serialized_end=513
  _globals['_FUNCTIONCONTROLGET']._serialized_start=515
  _globals['_FUNCTIONCONTROLGET']._serialized_end=535
  _globals['_FRAME']._serialized_start=537
  _globals['_FRAME']._serialized_end=627
  _globals['_FUNCTIONCONTROLSET']._serialized_start=629
  _globals['_FUNCTIONCONTROLSET']._serialized_end=678
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_start=680
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_end=757
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_start=759
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_end=787
  _globals['_STREAMCONTROLSTART']._serialized_start=789
  _globals['_STREAMCONTROLSTART']._serialized_end=857
  _globals['_SAMPLE']._serialized_start=860
  _globals['_SAMPLE']._serialized_end=1020
  _globals['_STREAMDATA']._serialized_start=1022
  _globals['_STREAMDATA']._serialized_end=1066
# @@protoc_insertion_point(module_scope)
