# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: binaryIoTypeC/v1alpha1/binaryIoTypeC.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*binaryIoTypeC/v1alpha1/binaryIoTypeC.proto\x12\rbinaryIoTypeC\"`\n\rChannelConfig\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x05\x12(\n\x04mode\x18\x02 \x01(\x0e\x32\x1a.binaryIoTypeC.ChannelMode\x12\x14\n\x0cinitialValue\x18\x03 \x01(\x08\"\xa0\x01\n\x10\x43onfigurationSet\x12\x33\n\rchannelConfig\x18\x01 \x03(\x0b\x32\x1c.binaryIoTypeC.ChannelConfig\x12\x1c\n\x14\x63hangeOutputWatchdog\x18\x02 \x01(\x08\x12\x1a\n\x12outputWatchdogMask\x18\x03 \x01(\x07\x12\x1d\n\x15outputWatchdogTimeout\x18\x04 \x01(\x07\"\x1a\n\x18\x43onfigurationSetResponse\"\x12\n\x10\x43onfigurationGet\"\x8a\x01\n\x18\x43onfigurationGetResponse\x12\x33\n\rchannelConfig\x18\x01 \x03(\x0b\x32\x1c.binaryIoTypeC.ChannelConfig\x12\x1a\n\x12outputWatchdogMask\x18\x03 \x01(\x07\x12\x1d\n\x15outputWatchdogTimeout\x18\x04 \x01(\x07\"\x17\n\x15\x43onfigurationDescribe\"9\n\x1d\x43onfigurationDescribeResponse\x12\x18\n\x10numberOfChannels\x18\x01 \x01(\x07\"\xd1\x01\n\x15\x43onfigurationResponse\x12\x36\n\x03get\x18\x01 \x01(\x0b\x32\'.binaryIoTypeC.ConfigurationGetResponseH\x00\x12\x36\n\x03set\x18\x02 \x01(\x0b\x32\'.binaryIoTypeC.ConfigurationSetResponseH\x00\x12@\n\x08\x64\x65scribe\x18\x03 \x01(\x0b\x32,.binaryIoTypeC.ConfigurationDescribeResponseH\x00\x42\x06\n\x04type\"\x1c\n\tGetSingle\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x07\"\x08\n\x06GetAll\"n\n\x12\x46unctionControlGet\x12*\n\x06single\x18\x01 \x01(\x0b\x32\x18.binaryIoTypeC.GetSingleH\x00\x12$\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x15.binaryIoTypeC.GetAllH\x00\x42\x06\n\x04type\"+\n\tSetSingle\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x07\x12\r\n\x05state\x18\x02 \x01(\x08\"&\n\x06SetAll\x12\x0e\n\x06values\x18\x01 \x01(\x07\x12\x0c\n\x04mask\x18\x02 \x01(\x07\"n\n\x12\x46unctionControlSet\x12*\n\x06single\x18\x01 \x01(\x0b\x32\x18.binaryIoTypeC.SetSingleH\x00\x12$\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x15.binaryIoTypeC.SetAllH\x00\x42\x06\n\x04type\"A\n\x11GetSingleResponse\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x07\x12\r\n\x05state\x18\x02 \x01(\x08\x12\x0c\n\x04\x64iag\x18\x03 \x01(\x07\".\n\x0eGetAllResponse\x12\x0e\n\x06inputs\x18\x01 \x01(\x07\x12\x0c\n\x04\x64iag\x18\x02 \x03(\r\"\x86\x01\n\x1a\x46unctionControlGetResponse\x12\x32\n\x06single\x18\x01 \x01(\x0b\x32 .binaryIoTypeC.GetSingleResponseH\x00\x12,\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x1d.binaryIoTypeC.GetAllResponseH\x00\x42\x06\n\x04type\"\x13\n\x11SetSingleResponse\"\x10\n\x0eSetAllResponse\"\x86\x01\n\x1a\x46unctionControlSetResponse\x12\x32\n\x06single\x18\x01 \x01(\x0b\x32 .binaryIoTypeC.SetSingleResponseH\x00\x12,\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x1d.binaryIoTypeC.SetAllResponseH\x00\x42\x06\n\x04type\"/\n\x12StreamControlStart\x12\x19\n\x11\x63hannelFilterMask\x18\x01 \x01(\x07\"@\n\x06Sample\x12\x11\n\ttimestamp\x18\x01 \x01(\x06\x12\x0e\n\x06values\x18\x02 \x01(\x07\x12\x13\n\x0bvalue_valid\x18\x03 \x01(\x07\"4\n\nStreamData\x12&\n\x07samples\x18\x01 \x03(\x0b\x32\x15.binaryIoTypeC.Sample*S\n\x0b\x43hannelMode\x12 \n\x1c\x42INARYIOTYPEC_INPUT_TYPE_1_3\x10\x00\x12\"\n\x1e\x42INARYIOTYPEC_OUTPUT_PUSH_PULL\x10\x01*}\n\x0b\x43hannelDiag\x12\n\n\x06NoDiag\x10\x00\x12\x13\n\x0fNoSupplyVoltage\x10\x01\x12\x10\n\x0c\x43urrentLimit\x10\x02\x12\x0c\n\x08Overload\x10\x04\x12\x16\n\x12SupplyUndervoltage\x10\x08\x12\x15\n\x11SupplyOvervoltage\x10\x10\x42\x18Z\x16\x62inaryIoTypeC/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'binaryIoTypeC.v1alpha1.binaryIoTypeC_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\026binaryIoTypeC/v1alpha1'
  _globals['_CHANNELMODE']._serialized_start=1753
  _globals['_CHANNELMODE']._serialized_end=1836
  _globals['_CHANNELDIAG']._serialized_start=1838
  _globals['_CHANNELDIAG']._serialized_end=1963
  _globals['_CHANNELCONFIG']._serialized_start=61
  _globals['_CHANNELCONFIG']._serialized_end=157
  _globals['_CONFIGURATIONSET']._serialized_start=160
  _globals['_CONFIGURATIONSET']._serialized_end=320
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_start=322
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_end=348
  _globals['_CONFIGURATIONGET']._serialized_start=350
  _globals['_CONFIGURATIONGET']._serialized_end=368
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_start=371
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_end=509
  _globals['_CONFIGURATIONDESCRIBE']._serialized_start=511
  _globals['_CONFIGURATIONDESCRIBE']._serialized_end=534
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_start=536
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_end=593
  _globals['_CONFIGURATIONRESPONSE']._serialized_start=596
  _globals['_CONFIGURATIONRESPONSE']._serialized_end=805
  _globals['_GETSINGLE']._serialized_start=807
  _globals['_GETSINGLE']._serialized_end=835
  _globals['_GETALL']._serialized_start=837
  _globals['_GETALL']._serialized_end=845
  _globals['_FUNCTIONCONTROLGET']._serialized_start=847
  _globals['_FUNCTIONCONTROLGET']._serialized_end=957
  _globals['_SETSINGLE']._serialized_start=959
  _globals['_SETSINGLE']._serialized_end=1002
  _globals['_SETALL']._serialized_start=1004
  _globals['_SETALL']._serialized_end=1042
  _globals['_FUNCTIONCONTROLSET']._serialized_start=1044
  _globals['_FUNCTIONCONTROLSET']._serialized_end=1154
  _globals['_GETSINGLERESPONSE']._serialized_start=1156
  _globals['_GETSINGLERESPONSE']._serialized_end=1221
  _globals['_GETALLRESPONSE']._serialized_start=1223
  _globals['_GETALLRESPONSE']._serialized_end=1269
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_start=1272
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_end=1406
  _globals['_SETSINGLERESPONSE']._serialized_start=1408
  _globals['_SETSINGLERESPONSE']._serialized_end=1427
  _globals['_SETALLRESPONSE']._serialized_start=1429
  _globals['_SETALLRESPONSE']._serialized_end=1445
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_start=1448
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_end=1582
  _globals['_STREAMCONTROLSTART']._serialized_start=1584
  _globals['_STREAMCONTROLSTART']._serialized_end=1631
  _globals['_SAMPLE']._serialized_start=1633
  _globals['_SAMPLE']._serialized_end=1697
  _globals['_STREAMDATA']._serialized_start=1699
  _globals['_STREAMDATA']._serialized_end=1751
# @@protoc_insertion_point(module_scope)
