# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pixelDisplay/v1alpha1/pixelDisplay.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(pixelDisplay/v1alpha1/pixelDisplay.proto\x12\x0cpixelDisplay\"\x12\n\x10\x43onfigurationSet\"\x1a\n\x18\x43onfigurationSetResponse\"\x12\n\x10\x43onfigurationGet\"\x1a\n\x18\x43onfigurationGetResponse\"\x17\n\x15\x43onfigurationDescribe\"d\n\x1d\x43onfigurationDescribeResponse\x12\x14\n\x0cheight_pixel\x18\x01 \x01(\x07\x12\x13\n\x0bwidth_pixel\x18\x02 \x01(\x07\x12\x18\n\x10max_num_of_pixel\x18\x03 \x01(\x07\"\xce\x01\n\x15\x43onfigurationResponse\x12\x35\n\x03get\x18\x01 \x01(\x0b\x32&.pixelDisplay.ConfigurationGetResponseH\x00\x12\x35\n\x03set\x18\x02 \x01(\x0b\x32&.pixelDisplay.ConfigurationSetResponseH\x00\x12?\n\x08\x64\x65scribe\x18\x03 \x01(\x0b\x32+.pixelDisplay.ConfigurationDescribeResponseH\x00\x42\x06\n\x04type\"\x14\n\x12\x46unctionControlGet\"N\n\x0cSetPixelArea\x12\x0f\n\x07start_x\x18\x01 \x01(\x07\x12\x0f\n\x07start_y\x18\x02 \x01(\x07\x12\r\n\x05\x65nd_x\x18\x03 \x01(\x07\x12\r\n\x05image\x18\x04 \x01(\x0c\"\x1a\n\x0cSetDisplayOn\x12\n\n\x02on\x18\x01 \x01(\x08\"\x84\x01\n\x12\x46unctionControlSet\x12\x34\n\x0eset_pixel_area\x18\x01 \x01(\x0b\x32\x1a.pixelDisplay.SetPixelAreaH\x00\x12\x30\n\ndisplay_on\x18\x02 \x01(\x0b\x32\x1a.pixelDisplay.SetDisplayOnH\x00\x42\x06\n\x04type\"\x1c\n\x1a\x46unctionControlGetResponse\"\x16\n\x14SetPixelAreaResponse\"\x16\n\x14SetDisplayOnResponse\"\x9c\x01\n\x1a\x46unctionControlSetResponse\x12<\n\x0eset_pixel_area\x18\x01 \x01(\x0b\x32\".pixelDisplay.SetPixelAreaResponseH\x00\x12\x38\n\ndisplay_on\x18\x02 \x01(\x0b\x32\".pixelDisplay.SetDisplayOnResponseH\x00\x42\x06\n\x04type\"\x14\n\x12StreamControlStart\"\x0c\n\nStreamDataB\x17Z\x15pixelDisplay/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pixelDisplay.v1alpha1.pixelDisplay_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\025pixelDisplay/v1alpha1'
  _globals['_CONFIGURATIONSET']._serialized_start=58
  _globals['_CONFIGURATIONSET']._serialized_end=76
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_start=78
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_end=104
  _globals['_CONFIGURATIONGET']._serialized_start=106
  _globals['_CONFIGURATIONGET']._serialized_end=124
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_start=126
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_end=152
  _globals['_CONFIGURATIONDESCRIBE']._serialized_start=154
  _globals['_CONFIGURATIONDESCRIBE']._serialized_end=177
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_start=179
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_end=279
  _globals['_CONFIGURATIONRESPONSE']._serialized_start=282
  _globals['_CONFIGURATIONRESPONSE']._serialized_end=488
  _globals['_FUNCTIONCONTROLGET']._serialized_start=490
  _globals['_FUNCTIONCONTROLGET']._serialized_end=510
  _globals['_SETPIXELAREA']._serialized_start=512
  _globals['_SETPIXELAREA']._serialized_end=590
  _globals['_SETDISPLAYON']._serialized_start=592
  _globals['_SETDISPLAYON']._serialized_end=618
  _globals['_FUNCTIONCONTROLSET']._serialized_start=621
  _globals['_FUNCTIONCONTROLSET']._serialized_end=753
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_start=755
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_end=783
  _globals['_SETPIXELAREARESPONSE']._serialized_start=785
  _globals['_SETPIXELAREARESPONSE']._serialized_end=807
  _globals['_SETDISPLAYONRESPONSE']._serialized_start=809
  _globals['_SETDISPLAYONRESPONSE']._serialized_end=831
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_start=834
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_end=990
  _globals['_STREAMCONTROLSTART']._serialized_start=992
  _globals['_STREAMCONTROLSTART']._serialized_end=1012
  _globals['_STREAMDATA']._serialized_start=1014
  _globals['_STREAMDATA']._serialized_end=1026
# @@protoc_insertion_point(module_scope)
