# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: binaryIoTypeB/v1alpha1/binaryIoTypeB.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*binaryIoTypeB/v1alpha1/binaryIoTypeB.proto\x12\rbinaryIoTypeB\"\x12\n\x10\x43onfigurationSet\"\x1a\n\x18\x43onfigurationSetResponse\"\x12\n\x10\x43onfigurationGet\"\x1a\n\x18\x43onfigurationGetResponse\"\x17\n\x15\x43onfigurationDescribe\"T\n\rChannelConfig\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x07\x12\x32\n\tdirection\x18\x02 \x01(\x0e\x32\x1f.binaryIoTypeB.ChannelDirection\"T\n\x1d\x43onfigurationDescribeResponse\x12\x33\n\rchannelConfig\x18\x01 \x03(\x0b\x32\x1c.binaryIoTypeB.ChannelConfig\"\xd1\x01\n\x15\x43onfigurationResponse\x12\x36\n\x03get\x18\x01 \x01(\x0b\x32\'.binaryIoTypeB.ConfigurationGetResponseH\x00\x12\x36\n\x03set\x18\x02 \x01(\x0b\x32\'.binaryIoTypeB.ConfigurationSetResponseH\x00\x12@\n\x08\x64\x65scribe\x18\x03 \x01(\x0b\x32,.binaryIoTypeB.ConfigurationDescribeResponseH\x00\x42\x06\n\x04type\"\x1c\n\tGetSingle\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x07\"\x16\n\x06GetAll\x12\x0c\n\x04mask\x18\x01 \x01(\x07\"n\n\x12\x46unctionControlGet\x12*\n\x06single\x18\x01 \x01(\x0b\x32\x18.binaryIoTypeB.GetSingleH\x00\x12$\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x15.binaryIoTypeB.GetAllH\x00\x42\x06\n\x04type\"+\n\tSetSingle\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x07\x12\r\n\x05state\x18\x02 \x01(\x08\"&\n\x06SetAll\x12\x0e\n\x06values\x18\x01 \x01(\x07\x12\x0c\n\x04mask\x18\x02 \x01(\x07\"n\n\x12\x46unctionControlSet\x12*\n\x06single\x18\x01 \x01(\x0b\x32\x18.binaryIoTypeB.SetSingleH\x00\x12$\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x15.binaryIoTypeB.SetAllH\x00\x42\x06\n\x04type\"3\n\x11GetSingleResponse\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x07\x12\r\n\x05state\x18\x02 \x01(\x08\" \n\x0eGetAllResponse\x12\x0e\n\x06inputs\x18\x01 \x01(\x07\"\x86\x01\n\x1a\x46unctionControlGetResponse\x12\x32\n\x06single\x18\x01 \x01(\x0b\x32 .binaryIoTypeB.GetSingleResponseH\x00\x12,\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x1d.binaryIoTypeB.GetAllResponseH\x00\x42\x06\n\x04type\"\x13\n\x11SetSingleResponse\"\x10\n\x0eSetAllResponse\"\x86\x01\n\x1a\x46unctionControlSetResponse\x12\x32\n\x06single\x18\x01 \x01(\x0b\x32 .binaryIoTypeB.SetSingleResponseH\x00\x12,\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x1d.binaryIoTypeB.SetAllResponseH\x00\x42\x06\n\x04type\"^\n\x10SubscribeChannel\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x07\x12\x39\n\x10subscriptionType\x18\x02 \x01(\x0e\x32\x1f.binaryIoTypeB.SubscriptionType\"O\n\x12StreamControlStart\x12\x39\n\x10subscribeChannel\x18\x01 \x03(\x0b\x32\x1f.binaryIoTypeB.SubscribeChannel\"+\n\x06Sample\x12\x11\n\ttimestamp\x18\x01 \x01(\x06\x12\x0e\n\x06inputs\x18\x02 \x01(\x07\"4\n\nStreamData\x12&\n\x07samples\x18\x01 \x03(\x0b\x32\x15.binaryIoTypeB.Sample*e\n\x10\x43hannelDirection\x12\x17\n\x13\x42INARYIOTYPEB_INPUT\x10\x00\x12\x18\n\x14\x42INARYIOTYPEB_OUTPUT\x10\x01\x12\x1e\n\x1a\x42INARYIOTYPEB_INPUT_OUTPUT\x10\x02*v\n\x10SubscriptionType\x12 \n\x1c\x42INARYIOTYPEB_ON_RISING_EDGE\x10\x00\x12!\n\x1d\x42INARYIOTYPEB_ON_FALLING_EDGE\x10\x01\x12\x1d\n\x19\x42INARYIOTYPEB_ON_ANY_EDGE\x10\x02\x42\x18Z\x16\x62inaryIoTypeB/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'binaryIoTypeB.v1alpha1.binaryIoTypeB_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\026binaryIoTypeB/v1alpha1'
  _globals['_CHANNELDIRECTION']._serialized_start=1605
  _globals['_CHANNELDIRECTION']._serialized_end=1706
  _globals['_SUBSCRIPTIONTYPE']._serialized_start=1708
  _globals['_SUBSCRIPTIONTYPE']._serialized_end=1826
  _globals['_CONFIGURATIONSET']._serialized_start=61
  _globals['_CONFIGURATIONSET']._serialized_end=79
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_start=81
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_end=107
  _globals['_CONFIGURATIONGET']._serialized_start=109
  _globals['_CONFIGURATIONGET']._serialized_end=127
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_start=129
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_end=155
  _globals['_CONFIGURATIONDESCRIBE']._serialized_start=157
  _globals['_CONFIGURATIONDESCRIBE']._serialized_end=180
  _globals['_CHANNELCONFIG']._serialized_start=182
  _globals['_CHANNELCONFIG']._serialized_end=266
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_start=268
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_end=352
  _globals['_CONFIGURATIONRESPONSE']._serialized_start=355
  _globals['_CONFIGURATIONRESPONSE']._serialized_end=564
  _globals['_GETSINGLE']._serialized_start=566
  _globals['_GETSINGLE']._serialized_end=594
  _globals['_GETALL']._serialized_start=596
  _globals['_GETALL']._serialized_end=618
  _globals['_FUNCTIONCONTROLGET']._serialized_start=620
  _globals['_FUNCTIONCONTROLGET']._serialized_end=730
  _globals['_SETSINGLE']._serialized_start=732
  _globals['_SETSINGLE']._serialized_end=775
  _globals['_SETALL']._serialized_start=777
  _globals['_SETALL']._serialized_end=815
  _globals['_FUNCTIONCONTROLSET']._serialized_start=817
  _globals['_FUNCTIONCONTROLSET']._serialized_end=927
  _globals['_GETSINGLERESPONSE']._serialized_start=929
  _globals['_GETSINGLERESPONSE']._serialized_end=980
  _globals['_GETALLRESPONSE']._serialized_start=982
  _globals['_GETALLRESPONSE']._serialized_end=1014
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_start=1017
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_end=1151
  _globals['_SETSINGLERESPONSE']._serialized_start=1153
  _globals['_SETSINGLERESPONSE']._serialized_end=1172
  _globals['_SETALLRESPONSE']._serialized_start=1174
  _globals['_SETALLRESPONSE']._serialized_end=1190
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_start=1193
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_end=1327
  _globals['_SUBSCRIBECHANNEL']._serialized_start=1329
  _globals['_SUBSCRIBECHANNEL']._serialized_end=1423
  _globals['_STREAMCONTROLSTART']._serialized_start=1425
  _globals['_STREAMCONTROLSTART']._serialized_end=1504
  _globals['_SAMPLE']._serialized_start=1506
  _globals['_SAMPLE']._serialized_end=1549
  _globals['_STREAMDATA']._serialized_start=1551
  _globals['_STREAMDATA']._serialized_end=1603
# @@protoc_insertion_point(module_scope)
