# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mvbSniffer/v1/telegram.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cmvbSniffer/v1/telegram.proto\x12\nmvbSniffer\"\xe6\x04\n\x08Telegram\x12\x11\n\ttimestamp\x18\x01 \x01(\x06\x12\r\n\x05state\x18\x02 \x01(\r\x12\'\n\x04type\x18\x03 \x01(\x0e\x32\x19.mvbSniffer.Telegram.Type\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\x12\x13\n\x0btelegram_nr\x18\x06 \x01(\x04\x12\'\n\x04line\x18\x07 \x01(\x0e\x32\x19.mvbSniffer.Telegram.Line\"S\n\x05State\x12\x0f\n\x0bkSuccessful\x10\x00\x12\r\n\tkTimedOut\x10\x01\x12\x14\n\x10kMissedMVBFrames\x10\x02\x12\x14\n\x10kMissedTelegrams\x10\x04\"\xc4\x02\n\x04Type\x12\x15\n\x11kProcessData16Bit\x10\x00\x12\x15\n\x11kProcessData32Bit\x10\x01\x12\x15\n\x11kProcessData64Bit\x10\x02\x12\x16\n\x12kProcessData128Bit\x10\x03\x12\x16\n\x12kProcessData256Bit\x10\x04\x12\x0f\n\x0bkReserved_1\x10\x05\x12\x0f\n\x0bkReserved_2\x10\x06\x12\x0f\n\x0bkReserved_3\x10\x07\x12\x17\n\x13kMastershipTransfer\x10\x08\x12\x11\n\rkGeneralEvent\x10\t\x12\x0f\n\x0bkReserved_4\x10\n\x12\x0f\n\x0bkReserved_5\x10\x0b\x12\x10\n\x0ckMessageData\x10\x0c\x12\x0f\n\x0bkGroupEvent\x10\r\x12\x10\n\x0ckSingleEvent\x10\x0e\x12\x11\n\rkDeviceStatus\x10\x0f\"\x16\n\x04Line\x12\x06\n\x02kA\x10\x00\x12\x06\n\x02kB\x10\x01\"9\n\x12TelegramCollection\x12#\n\x05\x65ntry\x18\x01 \x03(\x0b\x32\x14.mvbSniffer.TelegramB\x0fZ\rmvbSniffer/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mvbSniffer.v1.telegram_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\rmvbSniffer/v1'
  _globals['_TELEGRAM']._serialized_start=45
  _globals['_TELEGRAM']._serialized_end=659
  _globals['_TELEGRAM_STATE']._serialized_start=225
  _globals['_TELEGRAM_STATE']._serialized_end=308
  _globals['_TELEGRAM_TYPE']._serialized_start=311
  _globals['_TELEGRAM_TYPE']._serialized_end=635
  _globals['_TELEGRAM_LINE']._serialized_start=637
  _globals['_TELEGRAM_LINE']._serialized_end=659
  _globals['_TELEGRAMCOLLECTION']._serialized_start=661
  _globals['_TELEGRAMCOLLECTION']._serialized_end=718
# @@protoc_insertion_point(module_scope)
