# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mvbSniffer/v1/mvbSniffer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1emvbSniffer/v1/mvbSniffer.proto\x12\nmvbSniffer\"\x12\n\x10\x43onfigurationSet\"\x1a\n\x18\x43onfigurationSetResponse\"\x12\n\x10\x43onfigurationGet\"\x1a\n\x18\x43onfigurationGetResponse\"\x17\n\x15\x43onfigurationDescribe\"\x1f\n\x1d\x43onfigurationDescribeResponse\"\x14\n\x12\x46unctionControlGet\"/\n\x12\x46unctionControlSet\x12\x19\n\x11generator_pattern\x18\x01 \x01(\t\"\x1c\n\x1a\x46unctionControlGetResponse\"\x1c\n\x1a\x46unctionControlSetResponse\"a\n\nFilterMask\x12\x13\n\x0b\x66_code_mask\x18\x01 \x01(\r\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\r\x12\x0c\n\x04mask\x18\x03 \x01(\r\x12\x1f\n\x17include_timedout_frames\x18\x04 \x01(\x08\"<\n\x12StreamControlStart\x12&\n\x06\x66ilter\x18\x01 \x03(\x0b\x32\x16.mvbSniffer.FilterMaskB\x0fZ\rmvbSniffer/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mvbSniffer.v1.mvbSniffer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\rmvbSniffer/v1'
  _globals['_CONFIGURATIONSET']._serialized_start=46
  _globals['_CONFIGURATIONSET']._serialized_end=64
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_start=66
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_end=92
  _globals['_CONFIGURATIONGET']._serialized_start=94
  _globals['_CONFIGURATIONGET']._serialized_end=112
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_start=114
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_end=140
  _globals['_CONFIGURATIONDESCRIBE']._serialized_start=142
  _globals['_CONFIGURATIONDESCRIBE']._serialized_end=165
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_start=167
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_end=198
  _globals['_FUNCTIONCONTROLGET']._serialized_start=200
  _globals['_FUNCTIONCONTROLGET']._serialized_end=220
  _globals['_FUNCTIONCONTROLSET']._serialized_start=222
  _globals['_FUNCTIONCONTROLSET']._serialized_end=269
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_start=271
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_end=299
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_start=301
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_end=329
  _globals['_FILTERMASK']._serialized_start=331
  _globals['_FILTERMASK']._serialized_end=428
  _globals['_STREAMCONTROLSTART']._serialized_start=430
  _globals['_STREAMCONTROLSTART']._serialized_end=490
# @@protoc_insertion_point(module_scope)
