# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mvbDebug/v1/mvbDebug.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1amvbDebug/v1/mvbDebug.proto\x12\x08mvbDebug\"\x12\n\x10\x43onfigurationSet\"\x1a\n\x18\x43onfigurationSetResponse\"\x12\n\x10\x43onfigurationGet\"\x1a\n\x18\x43onfigurationGetResponse\"\x17\n\x15\x43onfigurationDescribe\"\x1f\n\x1d\x43onfigurationDescribeResponse\"\x14\n\x12\x46unctionControlGet\"/\n\x12\x46unctionControlSet\x12\x19\n\x11generator_pattern\x18\x01 \x01(\t\"+\n\x1a\x46unctionControlGetResponse\x12\r\n\x05value\x18\x01 \x01(\x02\"\x1c\n\x1a\x46unctionControlSetResponse\"\x14\n\x12StreamControlStart\"#\n\x06Sample\x12\x19\n\x11transitions_block\x18\x01 \x01(\x0c\"/\n\nStreamData\x12!\n\x07samples\x18\x01 \x03(\x0b\x32\x10.mvbDebug.SampleB\rZ\x0bmvbDebug/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mvbDebug.v1.mvbDebug_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\013mvbDebug/v1'
  _globals['_CONFIGURATIONSET']._serialized_start=40
  _globals['_CONFIGURATIONSET']._serialized_end=58
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_start=60
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_end=86
  _globals['_CONFIGURATIONGET']._serialized_start=88
  _globals['_CONFIGURATIONGET']._serialized_end=106
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_start=108
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_end=134
  _globals['_CONFIGURATIONDESCRIBE']._serialized_start=136
  _globals['_CONFIGURATIONDESCRIBE']._serialized_end=159
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_start=161
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_end=192
  _globals['_FUNCTIONCONTROLGET']._serialized_start=194
  _globals['_FUNCTIONCONTROLGET']._serialized_end=214
  _globals['_FUNCTIONCONTROLSET']._serialized_start=216
  _globals['_FUNCTIONCONTROLSET']._serialized_end=263
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_start=265
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_end=308
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_start=310
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_end=338
  _globals['_STREAMCONTROLSTART']._serialized_start=340
  _globals['_STREAMCONTROLSTART']._serialized_end=360
  _globals['_SAMPLE']._serialized_start=362
  _globals['_SAMPLE']._serialized_end=397
  _globals['_STREAMDATA']._serialized_start=399
  _globals['_STREAMDATA']._serialized_end=446
# @@protoc_insertion_point(module_scope)
