# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: inventory/v1alpha1/io4edge_inventory.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*inventory/v1alpha1/io4edge_inventory.proto\x12\x10io4edgeInventory\"C\n\x04Unit\x12\x14\n\x0croot_article\x18\x01 \x01(\t\x12\x15\n\rmajor_version\x18\x02 \x01(\r\x12\x0e\n\x06serial\x18\x03 \x01(\tB\x14Z\x12inventory/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'inventory.v1alpha1.io4edge_inventory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\022inventory/v1alpha1'
  _globals['_UNIT']._serialized_start=64
  _globals['_UNIT']._serialized_end=131
# @@protoc_insertion_point(module_scope)
