# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: templateInterface/v1alpha1/templateInterface.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2templateInterface/v1alpha1/templateInterface.proto\x12\x11templateInterface\"\'\n\x10\x43onfigurationSet\x12\x13\n\x0bsample_rate\x18\x01 \x01(\x07\"\x1a\n\x18\x43onfigurationSetResponse\"\x12\n\x10\x43onfigurationGet\"/\n\x18\x43onfigurationGetResponse\x12\x13\n\x0bsample_rate\x18\x01 \x01(\x07\"\x17\n\x15\x43onfigurationDescribe\".\n\x1d\x43onfigurationDescribeResponse\x12\r\n\x05ident\x18\x01 \x01(\t\"\xdd\x01\n\x15\x43onfigurationResponse\x12:\n\x03get\x18\x01 \x01(\x0b\x32+.templateInterface.ConfigurationGetResponseH\x00\x12:\n\x03set\x18\x02 \x01(\x0b\x32+.templateInterface.ConfigurationSetResponseH\x00\x12\x44\n\x08\x64\x65scribe\x18\x03 \x01(\x0b\x32\x30.templateInterface.ConfigurationDescribeResponseH\x00\x42\x06\n\x04type\"\x14\n\x12\x46unctionControlGet\"#\n\x12\x46unctionControlSet\x12\r\n\x05value\x18\x01 \x01(\x07\"+\n\x1a\x46unctionControlGetResponse\x12\r\n\x05value\x18\x01 \x01(\x07\"\x1c\n\x1a\x46unctionControlSetResponse\"$\n\x12StreamControlStart\x12\x0e\n\x06modulo\x18\x01 \x01(\x07\"*\n\x06Sample\x12\x11\n\ttimestamp\x18\x01 \x01(\x06\x12\r\n\x05value\x18\x02 \x01(\x07\"8\n\nStreamData\x12*\n\x07samples\x18\x01 \x03(\x0b\x32\x19.templateInterface.SampleB\x1cZ\x1atemplateInterface/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'templateInterface.v1alpha1.templateInterface_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\032templateInterface/v1alpha1'
  _globals['_CONFIGURATIONSET']._serialized_start=73
  _globals['_CONFIGURATIONSET']._serialized_end=112
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_start=114
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_end=140
  _globals['_CONFIGURATIONGET']._serialized_start=142
  _globals['_CONFIGURATIONGET']._serialized_end=160
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_start=162
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_end=209
  _globals['_CONFIGURATIONDESCRIBE']._serialized_start=211
  _globals['_CONFIGURATIONDESCRIBE']._serialized_end=234
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_start=236
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_end=282
  _globals['_CONFIGURATIONRESPONSE']._serialized_start=285
  _globals['_CONFIGURATIONRESPONSE']._serialized_end=506
  _globals['_FUNCTIONCONTROLGET']._serialized_start=508
  _globals['_FUNCTIONCONTROLGET']._serialized_end=528
  _globals['_FUNCTIONCONTROLSET']._serialized_start=530
  _globals['_FUNCTIONCONTROLSET']._serialized_end=565
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_start=567
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_end=610
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_start=612
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_end=640
  _globals['_STREAMCONTROLSTART']._serialized_start=642
  _globals['_STREAMCONTROLSTART']._serialized_end=678
  _globals['_SAMPLE']._serialized_start=680
  _globals['_SAMPLE']._serialized_end=722
  _globals['_STREAMDATA']._serialized_start=724
  _globals['_STREAMDATA']._serialized_end=780
# @@protoc_insertion_point(module_scope)
