# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: motionSensor/v1/motionSensor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"motionSensor/v1/motionSensor.proto\x12\x0cmotionSensor\"\x80\x01\n\x10\x43onfigurationSet\x12\x1b\n\x13sample_rate_milliHz\x18\x01 \x01(\x07\x12\x14\n\x0c\x66ull_scale_g\x18\x02 \x01(\x05\x12\x1f\n\x17high_pass_filter_enable\x18\x03 \x01(\x08\x12\x18\n\x10\x62\x61nd_width_ratio\x18\x04 \x01(\x05\"\x1a\n\x18\x43onfigurationSetResponse\"\x12\n\x10\x43onfigurationGet\"\x88\x01\n\x18\x43onfigurationGetResponse\x12\x1b\n\x13sample_rate_millihz\x18\x01 \x01(\x07\x12\x14\n\x0c\x66ull_scale_g\x18\x02 \x01(\x05\x12\x1f\n\x17high_pass_filter_enable\x18\x03 \x01(\x08\x12\x18\n\x10\x62\x61nd_width_ratio\x18\x04 \x01(\x05\"\x17\n\x15\x43onfigurationDescribe\"\x1f\n\x1d\x43onfigurationDescribeResponse\"\x14\n\x12\x46unctionControlGet\"\x14\n\x12\x46unctionControlSet\"\x1c\n\x1a\x46unctionControlGetResponse\"\x1c\n\x1a\x46unctionControlSetResponse\"\x14\n\x12StreamControlStart\"<\n\x06Sample\x12\x11\n\ttimestamp\x18\x01 \x01(\x06\x12\t\n\x01x\x18\x02 \x01(\x02\x12\t\n\x01y\x18\x03 \x01(\x02\x12\t\n\x01z\x18\x04 \x01(\x02\"3\n\nStreamData\x12%\n\x07samples\x18\x01 \x03(\x0b\x32\x14.motionSensor.SampleB\x11Z\x0fmotionSensor/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'motionSensor.v1.motionSensor_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\017motionSensor/v1'
  _globals['_CONFIGURATIONSET']._serialized_start=53
  _globals['_CONFIGURATIONSET']._serialized_end=181
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_start=183
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_end=209
  _globals['_CONFIGURATIONGET']._serialized_start=211
  _globals['_CONFIGURATIONGET']._serialized_end=229
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_start=232
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_end=368
  _globals['_CONFIGURATIONDESCRIBE']._serialized_start=370
  _globals['_CONFIGURATIONDESCRIBE']._serialized_end=393
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_start=395
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_end=426
  _globals['_FUNCTIONCONTROLGET']._serialized_start=428
  _globals['_FUNCTIONCONTROLGET']._serialized_end=448
  _globals['_FUNCTIONCONTROLSET']._serialized_start=450
  _globals['_FUNCTIONCONTROLSET']._serialized_end=470
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_start=472
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_end=500
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_start=502
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_end=530
  _globals['_STREAMCONTROLSTART']._serialized_start=532
  _globals['_STREAMCONTROLSTART']._serialized_end=552
  _globals['_SAMPLE']._serialized_start=554
  _globals['_SAMPLE']._serialized_end=614
  _globals['_STREAMDATA']._serialized_start=616
  _globals['_STREAMDATA']._serialized_end=667
# @@protoc_insertion_point(module_scope)
