# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: binaryIoTypeA/v1alpha1/binaryIoTypeA.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*binaryIoTypeA/v1alpha1/binaryIoTypeA.proto\x12\rbinaryIoTypeA\"i\n\x10\x43onfigurationSet\x12\x1a\n\x12outputFrittingMask\x18\x01 \x01(\x07\x12\x1a\n\x12outputWatchdogMask\x18\x02 \x01(\x07\x12\x1d\n\x15outputWatchdogTimeout\x18\x03 \x01(\x07\"\x1a\n\x18\x43onfigurationSetResponse\"\x12\n\x10\x43onfigurationGet\"q\n\x18\x43onfigurationGetResponse\x12\x1a\n\x12outputFrittingMask\x18\x01 \x01(\x07\x12\x1a\n\x12outputWatchdogMask\x18\x02 \x01(\x07\x12\x1d\n\x15outputWatchdogTimeout\x18\x03 \x01(\x07\"\x17\n\x15\x43onfigurationDescribe\"9\n\x1d\x43onfigurationDescribeResponse\x12\x18\n\x10numberOfChannels\x18\x01 \x01(\x07\"+\n\tSetSingle\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x07\x12\r\n\x05state\x18\x02 \x01(\x08\"&\n\x06SetAll\x12\x0e\n\x06values\x18\x01 \x01(\x07\x12\x0c\n\x04mask\x18\x02 \x01(\x07\"\x0e\n\x0cSetExitError\"\xa1\x01\n\x12\x46unctionControlSet\x12*\n\x06single\x18\x01 \x01(\x0b\x32\x18.binaryIoTypeA.SetSingleH\x00\x12$\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x15.binaryIoTypeA.SetAllH\x00\x12\x31\n\nexit_error\x18\x03 \x01(\x0b\x32\x1b.binaryIoTypeA.SetExitErrorH\x00\x42\x06\n\x04type\"\x1c\n\tGetSingle\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x07\"\x16\n\x06GetAll\x12\x0c\n\x04mask\x18\x01 \x01(\x07\"n\n\x12\x46unctionControlGet\x12*\n\x06single\x18\x01 \x01(\x0b\x32\x18.binaryIoTypeA.GetSingleH\x00\x12$\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x15.binaryIoTypeA.GetAllH\x00\x42\x06\n\x04type\" \n\x0eGetAllResponse\x12\x0e\n\x06inputs\x18\x01 \x01(\x07\"3\n\x11GetSingleResponse\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x07\x12\r\n\x05state\x18\x02 \x01(\x08\"\x86\x01\n\x1a\x46unctionControlGetResponse\x12\x32\n\x06single\x18\x01 \x01(\x0b\x32 .binaryIoTypeA.GetSingleResponseH\x00\x12,\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x1d.binaryIoTypeA.GetAllResponseH\x00\x42\x06\n\x04type\"\x10\n\x0eSetAllResponse\"\x13\n\x11SetSingleResponse\"\x86\x01\n\x1a\x46unctionControlSetResponse\x12\x32\n\x06single\x18\x01 \x01(\x0b\x32 .binaryIoTypeA.SetSingleResponseH\x00\x12,\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x1d.binaryIoTypeA.SetAllResponseH\x00\x42\x06\n\x04type\"/\n\x12StreamControlStart\x12\x19\n\x11\x63hannelFilterMask\x18\x01 \x01(\x07\";\n\x06Sample\x12\x11\n\ttimestamp\x18\x01 \x01(\x06\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\x07\x12\r\n\x05value\x18\x03 \x01(\x08\"4\n\nStreamData\x12&\n\x07samples\x18\x01 \x03(\x0b\x32\x15.binaryIoTypeA.SampleB\x18Z\x16\x62inaryIoTypeA/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'binaryIoTypeA.v1alpha1.binaryIoTypeA_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\026binaryIoTypeA/v1alpha1'
  _globals['_CONFIGURATIONSET']._serialized_start=61
  _globals['_CONFIGURATIONSET']._serialized_end=166
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_start=168
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_end=194
  _globals['_CONFIGURATIONGET']._serialized_start=196
  _globals['_CONFIGURATIONGET']._serialized_end=214
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_start=216
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_end=329
  _globals['_CONFIGURATIONDESCRIBE']._serialized_start=331
  _globals['_CONFIGURATIONDESCRIBE']._serialized_end=354
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_start=356
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_end=413
  _globals['_SETSINGLE']._serialized_start=415
  _globals['_SETSINGLE']._serialized_end=458
  _globals['_SETALL']._serialized_start=460
  _globals['_SETALL']._serialized_end=498
  _globals['_SETEXITERROR']._serialized_start=500
  _globals['_SETEXITERROR']._serialized_end=514
  _globals['_FUNCTIONCONTROLSET']._serialized_start=517
  _globals['_FUNCTIONCONTROLSET']._serialized_end=678
  _globals['_GETSINGLE']._serialized_start=680
  _globals['_GETSINGLE']._serialized_end=708
  _globals['_GETALL']._serialized_start=710
  _globals['_GETALL']._serialized_end=732
  _globals['_FUNCTIONCONTROLGET']._serialized_start=734
  _globals['_FUNCTIONCONTROLGET']._serialized_end=844
  _globals['_GETALLRESPONSE']._serialized_start=846
  _globals['_GETALLRESPONSE']._serialized_end=878
  _globals['_GETSINGLERESPONSE']._serialized_start=880
  _globals['_GETSINGLERESPONSE']._serialized_end=931
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_start=934
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_end=1068
  _globals['_SETALLRESPONSE']._serialized_start=1070
  _globals['_SETALLRESPONSE']._serialized_end=1086
  _globals['_SETSINGLERESPONSE']._serialized_start=1088
  _globals['_SETSINGLERESPONSE']._serialized_end=1107
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_start=1110
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_end=1244
  _globals['_STREAMCONTROLSTART']._serialized_start=1246
  _globals['_STREAMCONTROLSTART']._serialized_end=1293
  _globals['_SAMPLE']._serialized_start=1295
  _globals['_SAMPLE']._serialized_end=1354
  _globals['_STREAMDATA']._serialized_start=1356
  _globals['_STREAMDATA']._serialized_end=1408
# @@protoc_insertion_point(module_scope)
