# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: functionblock/v1alpha1/io4edge_functionblock.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2functionblock/v1alpha1/io4edge_functionblock.proto\x12\rfunctionblock\x1a\x19google/protobuf/any.proto\"\x18\n\x07\x43ontext\x12\r\n\x05value\x18\x01 \x01(\t\"\xe3\x01\n\x07\x43ommand\x12\'\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x16.functionblock.Context\x12\x35\n\rConfiguration\x18\x02 \x01(\x0b\x32\x1c.functionblock.ConfigurationH\x00\x12\x39\n\x0f\x66unctionControl\x18\x03 \x01(\x0b\x32\x1e.functionblock.FunctionControlH\x00\x12\x35\n\rstreamControl\x18\x04 \x01(\x0b\x32\x1c.functionblock.StreamControlH\x00\x42\x06\n\x04type\"\xe4\x01\n\rConfiguration\x12@\n functionSpecificConfigurationSet\x18\n \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12@\n functionSpecificConfigurationGet\x18\x14 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x45\n%functionSpecificConfigurationDescribe\x18\x1e \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\x08\n\x06\x61\x63tion\"\xa3\x01\n\x0f\x46unctionControl\x12\x42\n\"functionSpecificFunctionControlSet\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x42\n\"functionSpecificFunctionControlGet\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\x08\n\x06\x61\x63tion\"\xbb\x01\n\x12StreamControlStart\x12\x15\n\rbucketSamples\x18\x01 \x01(\x07\x12\x19\n\x11keepaliveInterval\x18\x02 \x01(\x07\x12\x17\n\x0f\x62ufferedSamples\x18\x03 \x01(\x07\x12@\n\"functionSpecificStreamControlStart\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x18\n\x10low_latency_mode\x18\x05 \x01(\x08\"\x13\n\x11StreamControlStop\"\x7f\n\rStreamControl\x12\x32\n\x05start\x18\x01 \x01(\x0b\x32!.functionblock.StreamControlStartH\x00\x12\x30\n\x04stop\x18\x02 \x01(\x0b\x32 .functionblock.StreamControlStopH\x00\x42\x08\n\x06\x61\x63tion\"\x16\n\x05\x45rror\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"\xec\x01\n\x15\x43onfigurationResponse\x12@\n functionSpecificConfigurationSet\x18\n \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12@\n functionSpecificConfigurationGet\x18\x14 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x45\n%functionSpecificConfigurationDescribe\x18\x1e \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\x08\n\x06\x61\x63tion\"\xab\x01\n\x17\x46unctionControlResponse\x12\x42\n\"functionSpecificFunctionControlSet\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x42\n\"functionSpecificFunctionControlGet\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\x08\n\x06\x61\x63tion\"\x17\n\x15StreamControlResponse\"u\n\nStreamData\x12\x1b\n\x13\x64\x65liveryTimestampUs\x18\x01 \x01(\x06\x12\x10\n\x08sequence\x18\x02 \x01(\x07\x12\x38\n\x1a\x66unctionSpecificStreamData\x18\n \x01(\x0b\x32\x14.google.protobuf.Any\"\xf5\x02\n\x08Response\x12\'\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x16.functionblock.Context\x12%\n\x06status\x18\x02 \x01(\x0e\x32\x15.functionblock.Status\x12#\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x14.functionblock.Error\x12=\n\rConfiguration\x18\x04 \x01(\x0b\x32$.functionblock.ConfigurationResponseH\x00\x12\x41\n\x0f\x66unctionControl\x18\x05 \x01(\x0b\x32&.functionblock.FunctionControlResponseH\x00\x12=\n\rstreamControl\x18\x06 \x01(\x0b\x32$.functionblock.StreamControlResponseH\x00\x12+\n\x06stream\x18\x07 \x01(\x0b\x32\x19.functionblock.StreamDataH\x00\x42\x06\n\x04type*\xf5\x01\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\x14\n\x10UNSPECIFIC_ERROR\x10\x01\x12\x13\n\x0fUNKNOWN_COMMAND\x10\x02\x12\x13\n\x0fNOT_IMPLEMENTED\x10\x03\x12\x10\n\x0cWRONG_CLIENT\x10\x04\x12\x15\n\x11INVALID_PARAMETER\x10\x05\x12\x0c\n\x08HW_FAULT\x10\x06\x12\x1a\n\x16STREAM_ALREADY_STARTED\x10\x07\x12\x1a\n\x16STREAM_ALREADY_STOPPED\x10\x08\x12\x17\n\x13STREAM_START_FAILED\x10\t\x12\x1b\n\x17TEMPORARILY_UNAVAILABLE\x10\nB\x18Z\x16\x66unctionblock/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'functionblock.v1alpha1.io4edge_functionblock_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\026functionblock/v1alpha1'
  _globals['_STATUS']._serialized_start=2047
  _globals['_STATUS']._serialized_end=2292
  _globals['_CONTEXT']._serialized_start=96
  _globals['_CONTEXT']._serialized_end=120
  _globals['_COMMAND']._serialized_start=123
  _globals['_COMMAND']._serialized_end=350
  _globals['_CONFIGURATION']._serialized_start=353
  _globals['_CONFIGURATION']._serialized_end=581
  _globals['_FUNCTIONCONTROL']._serialized_start=584
  _globals['_FUNCTIONCONTROL']._serialized_end=747
  _globals['_STREAMCONTROLSTART']._serialized_start=750
  _globals['_STREAMCONTROLSTART']._serialized_end=937
  _globals['_STREAMCONTROLSTOP']._serialized_start=939
  _globals['_STREAMCONTROLSTOP']._serialized_end=958
  _globals['_STREAMCONTROL']._serialized_start=960
  _globals['_STREAMCONTROL']._serialized_end=1087
  _globals['_ERROR']._serialized_start=1089
  _globals['_ERROR']._serialized_end=1111
  _globals['_CONFIGURATIONRESPONSE']._serialized_start=1114
  _globals['_CONFIGURATIONRESPONSE']._serialized_end=1350
  _globals['_FUNCTIONCONTROLRESPONSE']._serialized_start=1353
  _globals['_FUNCTIONCONTROLRESPONSE']._serialized_end=1524
  _globals['_STREAMCONTROLRESPONSE']._serialized_start=1526
  _globals['_STREAMCONTROLRESPONSE']._serialized_end=1549
  _globals['_STREAMDATA']._serialized_start=1551
  _globals['_STREAMDATA']._serialized_end=1668
  _globals['_RESPONSE']._serialized_start=1671
  _globals['_RESPONSE']._serialized_end=2044
# @@protoc_insertion_point(module_scope)
